﻿/* License
 * 
 * The MIT License (MIT)
 *
 * Copyright (c) 2013, Sylvain PONTOREAU (pontoreau.sylvain@outlook.com / sylvain.pontoreau.com)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using System;
using Xlsx.ComponentModel.Enums;

namespace Xlsx.ComponentModel.DataAnnotations
{
    /// <summary>
    /// Annotation to specified a bindable property.
    /// </summary>
    [AttributeUsage(AttributeTargets.Property, AllowMultiple = true, Inherited = true)]
    public sealed class XlsxBindablePropertyAttribute : Attribute
    {
        /// <summary>
        /// XlsxBindableInfo
        /// </summary>
        public XlsxBindableInfo BindableInfo { get; private set; }

        /// <summary>
        /// Create a new instance of XlsxBindablePropertyAttribute.
        /// </summary>
        /// <param name="type">Xlsx Data type.</param>
        /// <param name="ColumnName">Column name, null by default.</param>
        /// <param name="order">Order index.</param>
        public XlsxBindablePropertyAttribute(XlsxDataType type, string ColumnName = null, int order = 0)
        {
            BindableInfo = new XlsxBindableInfo();
            BindableInfo.ColumnName = ColumnName;
            BindableInfo.Type = type;
            BindableInfo.Order = order;
        }
    }
}
