﻿/* License
 * 
 * The MIT License (MIT)
 *
 * Copyright (c) 2013, Sylvain PONTOREAU (pontoreau.sylvain@outlook.com / sylvain.pontoreau.com)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using System;
using Xlsx.ComponentModel;

namespace Xlsx.DataBinder.Events
{
    /// <summary>
    /// Provides data for the RowDataBound events.
    /// </summary>
    public sealed class RowEventArgs<T> : EventArgs where T : class
    {
        /// <summary>
        /// Gets the XlsxDataSheet parent of the row.
        /// </summary>
        public XlsxDataSheet<T> XlsxDataSheet { get; private set; }

        /// <summary>
        /// Gets the data of the row.
        /// </summary>
        public T RowData { get; private set; }

        /// <summary>
        /// Create a new instance of RowEventArgs
        /// </summary>
        /// <param name="sheet">XlsxDataSheet parent of data</param>
        /// <param name="data">T data of the row</param>
        public RowEventArgs(XlsxDataSheet<T> sheet, T data)
        {
            XlsxDataSheet = sheet;
            RowData = data;
        }
    }
}
